@@ -17,7 +17,7 @@ efficiency of a user's sample.
 Examples:
     Create a single efficiency histogram for a single PID cut::
 
-        $ python -m pidcalib2.make_eff_hists --sample=Turbo18 --magnet=up \
+        $ python -m src.pidcalib2.make_eff_hists --sample=Turbo18 --magnet=up \
             --particle=Pi --pid-cut="DLLK > 4" --bin-var=P --bin-var=ETA \
             --bin-var=nSPDHits --output-dir=pidcalib_output
 
@@ -25,7 +25,7 @@ Examples:
     in data, so specifying multiple cuts is much faster than running
     make_eff_hists sequentially)::
 
-        $ python -m pidcalib2.make_eff_hists --sample=Turbo16 --magnet=up \
+        $ python -m src.pidcalib2.make_eff_hists --sample=Turbo16 --magnet=up \
             --particle=Pi --pid-cut="DLLK > 0" --pid-cut="DLLK > 4" \
             --pid-cut="DLLK > 6" --bin-var=P --bin-var=ETA \
             --bin-var=nSPDHits --output-dir=pidcalib_output
@@ -41,7 +41,7 @@ import sys
 import logzero
 from logzero import logger as log
 
-from . import binning, markdown_table, pid_data, utils
+from . import argparse_actions, binning, utils
 
 try:
     from .version import version  # type: ignore
@@ -49,42 +49,6 @@ except ImportError:
     version = "N/A"
 
 
-class ListValidAction(argparse.Action):
-    """Class that overrides required parameters and prints valid configs."""
-
-    def __call__(self, parser, namespace, values, option_string=None):
-
-        if values == "configs" or values.endswith(".json"):
-            header = ["Sample", "Magnet", "Particle"]
-            table = markdown_table.MarkdownTable(header)
-
-            # Print configs from the default samples.json if no file specified
-            if values == "configs":
-                values = None
-
-            for entry in pid_data.get_calibration_samples(values).keys():
-                try:
-                    sample, magnet, particle = entry.split("-")
-                    magnet = magnet[3:].lower()
-                    table.add_row([sample, magnet, particle])
-                except ValueError:
-                    # Skip group entries like "Turbo18-MagUp"
-                    pass
-
-            table.print()
-
-        elif values == "aliases":
-            table_pid = markdown_table.MarkdownTable(["Alias", "Variable"])
-            for alias, var in pid_data.aliases.items():
-                table_pid.add_row([alias, var])
-            table_pid.print()
-        else:
-            log.error(f"'{values}' is not a known keyword for list-valid")
-            raise KeyError
-
-        parser.exit()
-
-
 def decode_arguments(args):
     """Decode CLI arguments."""
     parser = argparse.ArgumentParser(
@@ -93,7 +57,7 @@ def decode_arguments(args):
     parser.add_argument(
         "-s",
         "--sample",
-        help="calibration sample (Turbo18, Electron16, ...)",
+        help="calibration sample; see pidcalib2.make_eff_hists --list configs",
         required=True,
         type=str,
     )
@@ -107,7 +71,7 @@ def decode_arguments(args):
     parser.add_argument(
         "-p",
         "--particle",
-        help="particle type",
+        help="particle type; see pidcalib2.make_eff_hists --list configs",
         required=True,
     )
     parser.add_argument(
@@ -153,7 +117,7 @@ def decode_arguments(args):
     parser.add_argument(
         "-l",
         "--list",
-        action=ListValidAction,
+        action=argparse_actions.ListValidAction,
         help="list all [configs, aliases]",
     )
     parser.add_argument(
@@ -219,13 +183,11 @@ def make_eff_hists(config: dict) -> None:
     output_dir = pathlib.Path(config["output_dir"])
     output_dir.mkdir(parents=True, exist_ok=True)
 
-    if config["binning_file"] is not None:
-        binning.load_binnings(config["binning_file"])
-
-    # Check that all binnings exist before reading files
-    for bin_var in config["bin_vars"]:
-        bin_edges = binning.get_binning(config["particle"], bin_var, verbose=True)
-        log.debug(f"{bin_var} binning: {bin_edges}")
+    binning.check_and_load_binnings(
+        config["particle"],
+        config["bin_vars"],
+        config["binning_file"] if "binning_file" in config else None,
+    )
 
     if config["local_dataframe"]:
         hists = utils.create_histograms_from_local_dataframe(config)
@@ -250,8 +212,6 @@ def make_eff_hists(config: dict) -> None:
                 pickle.dump(eff_hists[f"eff_{cut}"], f)
                 pickle.dump(eff_hists[f"passing_{cut}"], f)
                 pickle.dump(eff_hists["total"], f)
-                pickle.dump(eff_hists[f"passing_sumw2_{cut}"], f)
-                pickle.dump(eff_hists["total_sumw2"], f)
 
             log.info(f"Efficiency histograms saved to '{eff_hist_path}'")
 
