@@ -9,6 +9,7 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 
+import collections
 import json
 import os
 import pickle
@@ -95,47 +96,57 @@ aliases = {
     "DLLe": "probe_PIDe",
     "DLLd": "probe_PIDd",
     "MC12TuneV2_ProbNNe": "probe_MC12TuneV2_ProbNNe",
+    "MC12TuneV2_ProbNNmu": "probe_MC12TuneV2_ProbNNmu",
     "MC12TuneV2_ProbNNghost": "probe_MC12TuneV2_ProbNNghost",
     "MC12TuneV2_ProbNNk": "probe_MC12TuneV2_ProbNNk",
     "MC12TuneV2_ProbNNp": "probe_MC12TuneV2_ProbNNp",
     "MC12TuneV2_ProbNNpi": "probe_MC12TuneV2_ProbNNpi",
     "MC12TuneV3_ProbNNe": "probe_MC12TuneV3_ProbNNe",
+    "MC12TuneV3_ProbNNmu": "probe_MC12TuneV3_ProbNNmu",
     "MC12TuneV3_ProbNNghost": "probe_MC12TuneV3_ProbNNghost",
     "MC12TuneV3_ProbNNk": "probe_MC12TuneV3_ProbNNk",
     "MC12TuneV3_ProbNNp": "probe_MC12TuneV3_ProbNNp",
     "MC12TuneV3_ProbNNpi": "probe_MC12TuneV3_ProbNNpi",
     "MC12TuneV4_ProbNNe": "probe_MC12TuneV4_ProbNNe",
+    "MC12TuneV4_ProbNNmu": "probe_MC12TuneV4_ProbNNmu",
     "MC12TuneV4_ProbNNghost": "probe_MC12TuneV4_ProbNNghost",
     "MC12TuneV4_ProbNNk": "probe_MC12TuneV4_ProbNNk",
     "MC12TuneV4_ProbNNp": "probe_MC12TuneV4_ProbNNp",
     "MC12TuneV4_ProbNNpi": "probe_MC12TuneV4_ProbNNpi",
     "MC15TuneV1_ProbNNe": "probe_MC15TuneV1_ProbNNe",
+    "MC15TuneV1_ProbNNmu": "probe_MC15TuneV1_ProbNNmu",
     "MC15TuneV1_ProbNNghost": "probe_MC15TuneV1_ProbNNghost",
     "MC15TuneV1_ProbNNk": "probe_MC15TuneV1_ProbNNk",
     "MC15TuneV1_ProbNNp": "probe_MC15TuneV1_ProbNNp",
     "MC15TuneV1_ProbNNpi": "probe_MC15TuneV1_ProbNNpi",
     "Brunel_MC12TuneV2_ProbNNe": "probe_Brunel_MC12TuneV2_ProbNNe",
+    "Brunel_MC12TuneV2_ProbNNmu": "probe_Brunel_MC12TuneV2_ProbNNmu",
     "Brunel_MC12TuneV2_ProbNNghost": "probe_Brunel_MC12TuneV2_ProbNNghost",
     "Brunel_MC12TuneV2_ProbNNk": "probe_Brunel_MC12TuneV2_ProbNNk",
     "Brunel_MC12TuneV2_ProbNNp": "probe_Brunel_MC12TuneV2_ProbNNp",
     "Brunel_MC12TuneV2_ProbNNpi": "probe_Brunel_MC12TuneV2_ProbNNpi",
     "Brunel_MC12TuneV3_ProbNNe": "probe_Brunel_MC12TuneV3_ProbNNe",
+    "Brunel_MC12TuneV3_ProbNNmu": "probe_Brunel_MC12TuneV3_ProbNNmu",
     "Brunel_MC12TuneV3_ProbNNghost": "probe_Brunel_MC12TuneV3_ProbNNghost",
     "Brunel_MC12TuneV3_ProbNNk": "probe_Brunel_MC12TuneV3_ProbNNk",
     "Brunel_MC12TuneV3_ProbNNp": "probe_Brunel_MC12TuneV3_ProbNNp",
     "Brunel_MC12TuneV3_ProbNNpi": "probe_Brunel_MC12TuneV3_ProbNNpi",
     "Brunel_MC12TuneV4_ProbNNe": "probe_Brunel_MC12TuneV4_ProbNNe",
+    "Brunel_MC12TuneV4_ProbNNmu": "probe_Brunel_MC12TuneV4_ProbNNmu",
     "Brunel_MC12TuneV4_ProbNNghost": "probe_Brunel_MC12TuneV4_ProbNNghost",
     "Brunel_MC12TuneV4_ProbNNk": "probe_Brunel_MC12TuneV4_ProbNNk",
     "Brunel_MC12TuneV4_ProbNNp": "probe_Brunel_MC12TuneV4_ProbNNp",
     "Brunel_MC12TuneV4_ProbNNpi": "probe_Brunel_MC12TuneV4_ProbNNpi",
     "Brunel_MC15TuneV1_ProbNNe": "probe_Brunel_MC15TuneV1_ProbNNe",
+    "Brunel_MC15TuneV1_ProbNNmu": "probe_Brunel_MC15TuneV1_ProbNNmu",
     "Brunel_MC15TuneV1_ProbNNghost": "probe_Brunel_MC15TuneV1_ProbNNghost",
     "Brunel_MC15TuneV1_ProbNNk": "probe_Brunel_MC15TuneV1_ProbNNk",
     "Brunel_MC15TuneV1_ProbNNp": "probe_Brunel_MC15TuneV1_ProbNNp",
     "Brunel_MC15TuneV1_ProbNNpi": "probe_Brunel_MC15TuneV1_ProbNNpi",
     "P": "probe_P",
     "Brunel_P": "probe_Brunel_P",
+    "PT": "probe_PT",
+    "Brunel_PT": "probe_Brunel_PT",
     "ETA": "probe_ETA",
     "Brunel_ETA": "probe_Brunel_ETA",
     "nTracks": "nTracks",
@@ -148,6 +159,10 @@ aliases = {
     "Brunel_IsMuon": "probe_Brunel_isMuon",
     "HasRich": "probe_hasRich",
     "Brunel_HasRich": "probe_Brunel_hasRich",
+    "IPCHI2": "probe_IPCHI2",
+    "Brunel_IPCHI2": "probe_Brunel_IPCHI2",
+    "TRACK_GHOSTPROB": "probe_TRACK_GHOSTPROB",
+    "Brunel_TRACK_GHOSTPROB": "probe_Brunel_TRACK_GHOSTPROB",
 }
 
 
@@ -168,7 +183,10 @@ def is_simple(sample: str) -> bool:
 def get_relevant_branch_names(
     pid_cuts: List[str], bin_vars: List[str], cuts: List[str] = None
 ) -> Dict[str, str]:
-    """Return a list of branch names relevant to the cuts and binning vars.
+    """Return a dict of branch names relevant to the cuts and binning vars.
+
+    The key is user-level variable name/alias. The value is the actual branch
+    name.
 
     Args:
         pid_cuts: Simplified user-level cut list, e.g., ["DLLK < 4"].
@@ -220,6 +238,19 @@ def get_relevant_branch_names(
                 else:
                     branch_names[cut_var] = aliases[cut_var]
 
+    if len(branch_names) != len(set(branch_names.values())):
+        duplicates = [
+            item
+            for item, count in collections.Counter(branch_names.values()).items()
+            if count > 1
+        ]
+        log.error(
+            (
+                "You are mixing aliases and raw variable names for the same "
+                f"variable(s): {duplicates}"
+            )
+        )
+        raise KeyError
     return branch_names
 
 
@@ -261,7 +292,7 @@ def get_reference_branch_name(prefix: str, bin_var: str, bin_var_branch: str) ->
     return f"{prefix}_{bin_var_branch}"
 
 
-def get_calibration_samples(samples_file: str = None):
+def get_calibration_samples(samples_file: str = None) -> Dict:
     """Return a dictionary of all files for all calibration samples.
 
     Args:
@@ -302,7 +333,12 @@ def get_calibration_sample(
     try:
         sample_dict = samples_dict[sample_name]
     except KeyError:
-        log.error(f"Sample '{sample_name}' not found in {samples_file}")
+        log.error(
+            (
+                f"Sample '{sample_name}' not found. "
+                "Consult 'pidcalib2.make_eff_hists --list configs'."
+            )
+        )
         raise
 
     calibration_sample = sample_dict.copy()
@@ -314,14 +350,24 @@ def get_calibration_sample(
         except KeyError:
             log.error(f"Linked sample '{link}' not found in {samples_file}")
             raise
+        # Copy configuration from the link (tuple_names, cuts, etc.), but only
+        # if it doesn't override the upstream configuration
+        for key, item in samples_dict[link].items():
+            if key == "files":
+                continue
+            if key not in calibration_sample:
+                calibration_sample[key] = item
 
     if max_files:
+        log.warning(
+            "You are using the --max-files option; it should be used only for testing"
+        )
         calibration_sample["files"] = calibration_sample["files"][:max_files]
     return calibration_sample
 
 
 def root_to_dataframe(
-    path: str, tree_names: List[str], branches: List[str]
+    path: str, tree_names: List[str], branches: List[str], calibration: bool = False
 ) -> pd.DataFrame:
     """Return DataFrame with requested branches from tree in ROOT file.
 
@@ -339,6 +385,15 @@ def root_to_dataframe(
     # message if this happens.
     try:
         root_file = uproot.open(path)
+    except FileNotFoundError as exc:
+        if "Server responded with an error: [3010]" in exc.args[0]:
+            log.error(
+                (
+                    "Permission denied; do you have Kerberos credentials? "
+                    "Try running 'kinit -f [USERNAME]@CERN.CH'"
+                )
+            )
+        raise
     except OSError as err:
         if "Operation expired" in err.args[0]:
             log.error(
@@ -355,19 +410,28 @@ def root_to_dataframe(
             tree = root_file[tree_name]
             dfs.append(tree.arrays(branches, library="pd"))  # type: ignore
         except uproot.exceptions.KeyInFileError as exc:  # type: ignore
-            similar_keys = utils.find_similar_strings(exc.key, list(aliases), 0.80)
+            similar_keys = []
+            if calibration:
+                aliases_in_tree = []
+                for alias, var in aliases.items():
+                    if var in tree.keys():  # type: ignore
+                        aliases_in_tree.append(alias)
+                similar_keys += utils.find_similar_strings(
+                    exc.key, aliases_in_tree, 0.80
+                )
+                similar_keys += utils.find_similar_strings(
+                    "probe_" + exc.key, tree.keys(), 0.80  # type: ignore
+                )
+            similar_keys += utils.find_similar_strings(exc.key, tree.keys(), 0.80)  # type: ignore # noqa
             similar_keys += utils.find_similar_strings(
-                exc.key, tree.keys(), 0.80  # type: ignore
-            )
-            similar_keys += utils.find_similar_strings(
-                "probe_" + exc.key, tree.keys(), 0.80  # type: ignore
+                exc.key.replace("Brunel", ""), tree.keys(), 0.80  # type: ignore
             )
             # Remove duplicates while preserving ordering
             similar_keys = list(dict.fromkeys(similar_keys))
             log.error(
                 (
                     f"Branch '{exc.key}' not found; similar aliases and/or branches "
-                    f"that exist: {similar_keys}"
+                    f"that exist in the tree: {similar_keys}"
                 )
             )
             raise
@@ -387,7 +451,9 @@ def root_to_dataframe(
     return pd.concat(dfs, ignore_index=True)  # type: ignore
 
 
-def get_tree_paths(particle: str, sample: str) -> List[str]:
+def get_tree_paths(
+    particle: str, sample: str, override_tuple_names: Dict[str, List[str]] = None
+) -> List[str]:
     """Return a list of internal ROOT paths to relevant trees in the files
 
     Args:
@@ -401,8 +467,13 @@ def get_tree_paths(particle: str, sample: str) -> List[str]:
         tree_paths.append("DecayTree")
     else:
         # Run 2 ROOT file structure with multiple trees
-        for tuple_name in tuple_names[particle]:
-            tree_paths.append(f"{tuple_name}/DecayTree")
+        if override_tuple_names and particle in override_tuple_names:
+            log.debug("Tree paths overriden by tuple_names")
+            for tuple_name in override_tuple_names[particle]:
+                tree_paths.append(f"{tuple_name}/DecayTree")
+        else:
+            for tuple_name in tuple_names[particle]:
+                tree_paths.append(f"{tuple_name}/DecayTree")
 
     return tree_paths
 
@@ -478,12 +549,20 @@ def get_calib_hists(
         log.debug(f"Loading efficiency histograms from '{calib_name}'")
 
         hists[ref_par] = {}
-        with open(calib_name, "rb") as f:
-            hists[ref_par]["eff"] = pickle.load(f)
-            hists[ref_par]["passing"] = pickle.load(f)
-            hists[ref_par]["total"] = pickle.load(f)
-            hists[ref_par]["passing_sumw2"] = pickle.load(f)
-            hists[ref_par]["total_sumw2"] = pickle.load(f)
+        try:
+            with open(calib_name, "rb") as f:
+                hists[ref_par]["eff"] = pickle.load(f)
+                hists[ref_par]["passing"] = pickle.load(f)
+                hists[ref_par]["total"] = pickle.load(f)
+        except FileNotFoundError:
+            log.error(
+                (
+                    "Efficiency histogram file not found. You must first "
+                    "run make_eff_hists with matching parameters to create the "
+                    "efficiency histograms."
+                )
+            )
+            raise
     return hists
 
 
