@@ -28,7 +28,7 @@ command line.
 Examples:
     Evaluate efficiency of a single PID cut and add it to the reference file::
 
-        $ python -m pidcalib2.ref_calib --sample=Turbo18 --magnet=up \
+        $ python -m src.pidcalib2.ref_calib --sample=Turbo18 --magnet=up \
             --ref-file=data/user_ntuple.root --output-dir=pidcalib_output \
             --bin-vars='{"P": "mom", "ETA": "Eta", "nSPDHits": "nSPDhits"}' \
             --ref-pars='{"Bach": ["K", "DLLK > 4"]}'
@@ -37,7 +37,7 @@ Examples:
     Evaluate efficiency of a single PID cut and save it to
     user_ntuple_PID_eff.root without adding it to user_ntuple.root::
 
-        $ python -m pidcalib2.ref_calib --sample=Turbo18 --magnet=up \
+        $ python -m src.pidcalib2.ref_calib --sample=Turbo18 --magnet=up \
             --ref-file=data/user_ntuple.root --output-dir=pidcalib_output \
             --bin-vars='{"P": "mom", "ETA": "Eta", "nSPDHits": "nSPDhits"}' \
             --ref-pars='{"Bach": ["K", "DLLK > 4"]}'
@@ -45,7 +45,7 @@ Examples:
     Evaluate efficiency of multiple PID cuts and add them to the reference
     file::
 
-        $ python -m pidcalib2.ref_calib --sample=Turbo18 --magnet=up \
+        $ python -m src.pidcalib2.ref_calib --sample=Turbo18 --magnet=up \
             --ref-file=data/user_ntuple.root --output-dir=pidcalib_output \
             --bin-vars='{"P": "P", "ETA": "ETA", "nSPDHits": "nSPDHits"}' \
             --ref-pars='{"Bach": ["K", "DLLK > 4"], "SPi": ["Pi", "DLLK < 0"]}'
@@ -62,7 +62,7 @@ from typing import Dict
 import logzero
 from logzero import logger as log
 
-from . import merge_trees, pid_data, utils
+from . import argparse_actions, merge_trees, pid_data, utils
 
 try:
     from .version import version  # type: ignore
@@ -109,6 +109,7 @@ def decode_arguments(args):
         "-o",
         "--output-file",
         help="ROOT filename into which to save the PID efficiency tree",
+        required=True,
     )
     parser.add_argument(
         "-f",
@@ -145,6 +146,12 @@ def decode_arguments(args):
         action="store_true",
         help="(debug) treat empty efficiency histogram bins as PIDCalib1 did",
     )
+    parser.add_argument(
+        "-l",
+        "--list",
+        action=argparse_actions.ListValidAction,
+        help="list all [configs, aliases]",
+    )
     parser.add_argument(
         "-v",
         "--verbose",
@@ -200,9 +207,12 @@ def ref_calib(config: Dict) -> float:
         log.error("The --ref-pars string is not valid Python dict")
         raise
 
-    ref_branches = pid_data.get_reference_branch_names(ref_pars, bin_vars)
+    eff_histos = pid_data.get_calib_hists(
+        config["histo_dir"], config["sample"], config["magnet"], ref_pars, bin_vars
+    )
 
     log.info(f"Loading reference sample '{config['ref_file']}' ...")
+    ref_branches = pid_data.get_reference_branch_names(ref_pars, bin_vars)
     df_ref = pid_data.root_to_dataframe(
         config["ref_file"], [config["ref_tree"]], ref_branches
     )
@@ -210,10 +220,6 @@ def ref_calib(config: Dict) -> float:
         f"Reference sample '{config['ref_file']}' with {len(df_ref.index)} events loaded"  # noqa
     )
 
-    eff_histos = pid_data.get_calib_hists(
-        config["histo_dir"], config["sample"], config["magnet"], ref_pars, bin_vars
-    )
-
     start = time.perf_counter()
     df_ref = utils.add_bin_indices(df_ref, list(ref_pars), bin_vars, eff_histos)
     df_ref = utils.add_efficiencies(df_ref, list(ref_pars), eff_histos)
